@@ -21,7 +21,8 @@ def ajax_required(function):
     """Decorator for requiring request to be and ajax one"""
     def wrap(request, *args, **kwargs):
         """Wrap function of decorator"""
-        if not request.is_ajax():
+        # Check if request isn't AJAX one
+        if not request.headers.get('x-requested-with') == 'XMLHttpRequest':
             return HttpResponseBadRequest()
         return function(request, *args, **kwargs)
 
