@@ -243,6 +243,26 @@ class Station(models.Model):
                 }
             )
 
+    def update_status(self, created: bool = False):
+        """
+        Update the status of the station
+
+        :param created: Whether the model is being created
+        """
+        if not created:
+            current_status = self.status
+            if self.is_offline:
+                self.status = 0
+            elif self.testing:
+                self.status = 1
+            else:
+                self.status = 2
+            self.save()
+            if self.status != current_status:
+                StationStatusLog.objects.create(station=self, status=self.status)
+        else:
+            StationStatusLog.objects.create(station=self, status=self.status)
+
 
 class AntennaType(models.Model):
     """Model for antenna types."""
@@ -346,7 +366,6 @@ class StationStatusLog(models.Model):
 class Satellite(models.Model):
     """Model for SatNOGS satellites."""
     norad_cat_id = models.PositiveIntegerField(db_index=True)
-    norad_follow_id = models.PositiveIntegerField(blank=True, null=True)
     name = models.CharField(max_length=45)
     names = models.TextField(blank=True)
     image = models.CharField(max_length=100, blank=True, null=True)
